.. _about:

About scippnexus
================

Development
-----------

Scippnexus is an open source project by the `European Spallation Source ERIC <https://europeanspallationsource.se/>`_ (ESS).

License
-------

Scippnexus is available as open source under the `BSD-3 license <https://opensource.org/licenses/BSD-3-Clause>`_.

Source code and development
---------------------------

Scippnexus is hosted and developed `on GitHub <https://github.com/scipp/scippnexus>`_.

Contributing to scippnexus
--------------------------

Contributions, bug reports, and ideas are always welcome.
If in doubt whether a feature falls within the scope of scippnexus please `ask on github <https://github.com/scipp/scippnexus/issues>`_ before implementing functionality, to reduce the risk of rejected pull requests.
Asking and discussing first is generally always a good idea, since our road map is not very mature at this point.
